PAWpySeed: sbt_descriptor Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
sbt_descriptor Struct Reference

`#include <sbt.h>`

## Public Attributes
double | kmin
| Minimum reciprocal space value. More...
double | kappamin
| ln(kmin) More...
double | rmin
| Minimum real space value. More...
double | rhomin
| ln(rmin) More...
double | drho
| linear increment of rho = ln(r), drho == dkappa More...
double | dt
| increment of the multiplication table More...
int | N
| number of values of r and k More...
double complex ** | mult_table
| M_l(t) for l up to lmax. More...
double * | ks
| Reciprocal space grid. More...
double * | rs
| Real space grid. More...
int | lmax

## Detailed Description

Contains the parameters for a fast spherical Bessel transform.

## Member Data Documentation

double sbt_descriptor::drho

linear increment of rho = ln(r), drho == dkappa

double sbt_descriptor::dt

increment of the multiplication table

double sbt_descriptor::kappamin

ln(kmin)

double sbt_descriptor::kmin

Minimum reciprocal space value.

double* sbt_descriptor::ks

Reciprocal space grid.

int sbt_descriptor::lmax

double complex** sbt_descriptor::mult_table

M_l(t) for l up to lmax.

int sbt_descriptor::N

number of values of r and k

double sbt_descriptor::rhomin

ln(rmin)

double sbt_descriptor::rmin

Minimum real space value.

double* sbt_descriptor::rs

Real space grid.

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/sbt.h